==> apache-camel-3.7.3-src.zip: apache-camel-3.7.3/test-infra/camel-test-infra-azure-storage-blob/src/test/java/org/apache/camel/test/infra/azure/storage/blob/services/AzureStorageBlobServiceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.test.infra.azure.storage.blob.services;

import org.apache.camel.test.infra.azure.common.services.AzureService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public final class AzureStorageBlobServiceFactory {
    private static final Logger LOG = LoggerFactory.getLogger(AzureStorageBlobServiceFactory.class);

    private AzureStorageBlobServiceFactory() {

    }

    public static AzureService createAzureService() {
        String instanceType = System.getProperty("azure.instance.type");

        if (instanceType == null || instanceType.equals("local-azure-container")) {
            return new AzureStorageBlobLocalContainerService();
        }

        if (instanceType.equals("remote")) {
            return new AzureStorageBlobRemoteService();
        }

        LOG.error("Azure instance must be one of 'local-azure-container' or 'remote");
        throw new UnsupportedOperationException(String.format("Invalid Azure instance type: %s", instanceType));
    }
}

==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/test-infra/camel-test-infra-azure-storage-blob/src/test/java/org/apache/camel/test/infra/azure/storage/blob/services/AzureStorageBlobServiceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.test.infra.azure.storage.blob.services;

import org.apache.camel.test.infra.azure.common.services.AzureService;
import org.apache.camel.test.infra.common.services.SimpleTestServiceBuilder;

public final class AzureStorageBlobServiceFactory {
    private AzureStorageBlobServiceFactory() {

    }

    public static SimpleTestServiceBuilder<AzureService> builder() {
        return new SimpleTestServiceBuilder<>("azure");
    }

    public static AzureService createService() {
        return builder()
                .addLocalMapping(AzureStorageBlobLocalContainerService::new)
                .addRemoteMapping(AzureStorageBlobRemoteService::new)
                .build();
    }
}
